setup.getStartingCharacter = function(id=undefined){
	id ??= State.variables.startCharacter;
	let currentData = clone(setup.startingCharacters[id]);
	currentData.inheritance = [id];
	if("parent" in currentData){
		let parentData = setup.getStartingCharacter(currentData.parent);
		let newcurrentData = setup.mergeDeep(parentData,currentData,{inheritance:[...parentData.inheritance,...currentData.inheritance]});

		currentData = newcurrentData;
		delete currentData.parent;
	}
	return currentData;
}

setup.getStartingCharactersByFilter = function(filters,shallow = true){
	let result = {};
	charLoop: for (const [charId, charData] of Object.entries(setup.startingCharacters)) {
		for (const [filterKey, filterValue] of Object.entries(filters)) {
			if(charData[filterKey] !== filterValue)
				continue charLoop;
			if(shallow)
				result[charId] = charData;
			else
				result[charId] = setup.getStartingCharacter(charId);
		}
	}
	return result;
}

setup.startingCharacterApply = function(characterId){
	const startCharacterData = setup.getStartingCharacter(characterId);
	const variables = State.variables;

	variables.startCharacter = characterId;

	variables.pc.avatar = startCharacterData.image;

	
	if(startCharacterData.time){
		if(startCharacterData.time.start){
			variables.time.initTime(
				startCharacterData.time.start[0],
				startCharacterData.time.start[1],
				startCharacterData.time.start[2],
				startCharacterData.time.start[3],
				startCharacterData.time.start[4]);
		}
	}

	variables.housing.home = startCharacterData.housing.home;

	for(const [_key,_value] of Object.entries(startCharacterData.pc ?? {})){
		variables.pc[_key] = _value;
	}


	for(const [_locationId,_locationValue] of Object.entries(startCharacterData.location ?? {})){
		for(const [_fieldId,_fieldValue] of Object.entries(_locationValue  ?? {})){
			variables.location.set(_locationId,_fieldId,_fieldValue);
		}
	}

	for(const [_locationTag,_locationTagValue] of Object.entries(startCharacterData.locationTags ?? {})){
		for(const [_fieldId,_fieldValue] of Object.entries(_locationTagValue  ?? {})){
			variables.location.setTagValue(_locationTag,_fieldId,_fieldValue);
		}
	}

	for(const [_key,_value] of Object.entries(startCharacterData.quests ?? {})){
		if(_value === true){
			variables.quest(_key).start();
		}
	}

	for(const [_key,_value] of Object.entries(startCharacterData.skills ?? {})){
		variables.pc.skillSetLevel(_key,_value);
	}

	for(const [_key,_value] of Object.entries(startCharacterData.traits ?? {})){
		variables.pc.traitSet(_key,_value);
	}

	for(const [_key,_value] of Object.entries(startCharacterData.finances ?? {})){
		variables.finances[_key] = _value;
	}

	for(const [_key,_value] of Object.entries(startCharacterData.items ?? {})){
		if(typeof _value == "number")
			variables.inventory.set(_key,_value);
		else if(typeof _value === "object"){
			if(_value.generateFunction)
				variables.inventory.set(_key,1,undefined,setup[_value.generateFunction](...(_value.generateParameters ?? [])));
			else
				variables.inventory.set(_key,1,undefined,_value);
			
		}
	}

	//<!-- NPCs -->
		//<!-- BULK -->
		for(const [_key,_value] of Object.entries(startCharacterData.npcs?.bulk ?? {})){
			let _filters = _value.filters ?? {};
			for(const [_fieldKey,_fieldValue] of Object.entries(_value.values ?? {})){
				variables.npcs.setBulkByFilter(_filters,_fieldKey,_fieldValue);
			}
		}
		//<!-- IDs: Need to come bulk so they don't get overwritten -->
		for(const [_key,_value] of Object.entries(startCharacterData.npcs?.ids ?? {})){
			for(const [_fieldKey,_fieldValue] of Object.entries(_value)){
				variables.npcs.set(_key,_fieldKey,_fieldValue);
			}
		}

	//<!-- School stuff -->
	if(startCharacterData.school){
		for(const [_key,_value] of Object.entries(startCharacterData.school.grades ?? {})){
			variables.quest('school').func('grade_award',_key,_value);
		}
		variables.quest('school').func('initGroupMembership',startCharacterData.school.group);
	}

	//<!--Wardrobe -->
	for(const [_key,_value] of Object.entries(startCharacterData.wardrobe?.items ?? {})){
		if(_value === 'wear')
			variables.wardrobe.wear(_key);
		else if(_value === 'add')
			variables.wardrobe.add(_key);
	}

	for(const [_key,_value] of Object.entries(startCharacterData.wardrobe?.itemsByFilter ?? {})){
		let _filters = _value.filters;
		let _count = _value.count ?? 1;
		let _action = _value.action ?? 'add';
		let _itemIds = variables.wardrobe.getItemIds(_filters,_count,true);
		for(const _itemId of _itemIds){
			switch(_action){
				case 'add':
					variables.wardrobe.add(_itemId);
					break;
				case 'wear':
					variables.wardrobe.wear(_itemId);
					break;
			}
		}
	}

}



setup.startingCharacterTagsIncludes = function(tag){
	const startData = setup.getStartingCharacter(State.variables.startCharacter) ?? {};
	const startDataTags = startData.tags ?? [];
	return startDataTags.includes(tag);
}


setup.startingCharacters ??= {};
setup.startingCharacters.default = {
	pc:{
		faceGeneticAttractiveness: 0,
		hairColor: 0,
		hairLength: 300,
		teethQuality: 1,
		tits: 2,
		pcs_hgt: 167
	},
	finances:{
		cash: 2000
	},
	items:{
		sanpad:10
	},
	npcs:{
		bulk:{
			parents_social:{
				filters:{
					group: 'group_parents_social'
				}
			}
		}
	}
};

setup.startingCharacters.sg_starting_category = {
	parent: 'default',
	housing:{
		home: 'homeParents'
	},
	quests:{
		school: true,
		school_mother: true,
		mother_virgin: true,
		christina: true
	},
	npcs:{
		bulk:{
			cool:{
				filters:{
					group: 'cool'
				},
				values:{
					fam: 150,
					rel: 30
				}
			},
			jocks:{
				filters:{
					group: 'jocks'
				},
				values:{
					fam: 150,
					rel: 30
				}
			},
			nerds:{
				filters:{
					group: 'nerds'
				},
				values:{
					fam: 150,
					rel: 30
				}
			},
			ouctasts:{
				filters:{
					group: 'ouctasts'
				},
				values:{
					fam: 150,
					rel: 30
				}
			},
			gopniks:{
				filters:{
					group: 'gopniks'
				},
				values:{
					fam: 150,
					rel: 30
				}
			},
			teachers:{
				filters:{
					group: 'teachers'
				},
				values:{
					fam: 50,
					rel: 50
				}
			}
		}
	},
	tags: ['sg']
}

setup.startingCharacters.nerd = {
	parent: 'sg_starting_category',
	label: 'Nerd',
	image: 'system/1_openings/2_sg/nerd_0.jpg',
	desc: 'Nerds, geeks and good students - These students tend to do well in school and are well liked by teachers and other adults. They tend to not have many friends outside of their own social group, however, and are also sometimes picked on or bullied. They are subpar athletically and place less value on looks and social skills than other cliques.',
	pc:{
		bmi: 24,
		legHairVisibility: 4,
		skinAppearance: 0,
		tan: 0
	},
	skills:{
		chess:20,
		computer:20,
		gaming:20,
		highHeels:5,
		inhibition:10,
		intelligence:45,
		makeup:15,
	},
	items:{
		nerd_startarting_book_1:{
			generateFunction:'generateBook',
			generateParameters:['fantasy']
		},
		nerd_startarting_book_2:{
			generateFunction:'generateBook',
			generateParameters:['scifi']
		}
	},
	finances:{
		cash: 5000
	},
	traits:{
		nerd_points:60,
		nerd_status:2,
		nerd_lernHome:5,
	},
	school:{
		grades:{	art:75,	bio:80,	comp:80,	eng:85,	geo:80,	his:80,	lit:80,	math:85,	mus:75,	pe:60,	rus:80,	sci:90,	shop:55	},
		group: 'nerds'
	},
	npcs:{
		bulk:{
			nerds:{
				values:{
					fam: 500,
					rel: 65
				}
			},
			parents_social:{
				values:{
					rel: 70
				}
			}
		}
	},
	tags: ['nerd']
};

setup.startingCharacters.nerd_queen = {
	parent: 'nerd',
	label: 'Queen of the nerds',
	image: 'system/1_openings/2_sg/nerd_1.jpg',
	desc: `While you love all things nerdy, what you love the most is hanging out with your fellow nerds and doing nerdy things together. This has made you fairly social for a nerd and more general in your areas of knowledge. As you got older and started to develop as a woman, it also made you much more aware of your sexuality than most nerds are comfortable with. As such, you cultivated that awareness more than most and are now more at ease with your body than most of the other nerds.
	By nerd standards, you are confident, dynamic and attractive and this has led to you being the leader of your group of friends. You are more acceptable to other social groups as a result, especially the cool kids, who seem to respect your social skills and looks.`,
	pc:{
		bmi: 20,
		faceGeneticAttractiveness: 1,
		hairColor: 3,
		legHairVisibility: 1,
		skinAppearance: 1,
		teethQuality:0,
		tits: 4,
		willpowermax: 70
	},
	skills:{
		charisma:40,
		highHeels:25,
		inhibition:20,
		makeup:30,
		people:20,
		persuasion:20,
		iceskating:10,
		spirit:40,
	},
	
	items:{
		cosmetics:10,
		razor:10
	},
	npcs:{
		bulk:{
			cool:{	values:{	fam: 300,	rel: 50}},
			jocks:{	values:{	fam: 200,	rel: 40}},
			nerds:{	values:{				rel: 75}},
			gopniks:{values:{	fam: 200,	rel: 20}},
			ouctasts:{values:{	fam: 200,	rel: 30}},
		}
	},
	wardrobe:{
		itemsByFilter:{
			anyFashionistaPurse:{
				filters:{
					vendor:'fashionista',
					type: 'purse'
				},
				action: 'wear'
			}
		}
	}
};

setup.startingCharacters.goodStudent = {
	parent: 'nerd',
	label: 'Good student',
	image: 'system/1_openings/2_sg/nerd_2.jpg',
	desc: `You just love school, and your grades are more than good enough to attend the university of your choosing after graduation - all you have to do is not let them slip. You have always tried to absorb every bit of knowledge possible and have done everything you can to excel in school. While this attitude has gained you a lot of respect from the other nerds, it didn't earn you a lot of friends and you never found the time for sports.
	You are often asked to be a tutor and sometimes find yourself forced to do others' homework for them. You have excellent grades, and your mother is very proud of you. She has shown her appreciation for your hard work by rewarding you with money.`,
	pc:{
		hairLength: 300,
		willpowermax: 75
	},
	skills:{
		intelligence:60,
		playInstrument:10,
		art:10,
	},
	traits:{
		nerd_points:100,
		nerd_status:3,
	},
	school:{
		grades:{	art:90,	bio:90,	comp:90,	eng:90,	geo:90,	his:90,	lit:90,	math:90,	mus:90,	pe:55,	rus:90,	sci:90,	shop:55	}
	},
	finances:{
		cash: 7000
	},
	items:{
	},
	npcs:{
	},
	wardrobe:{
	}
};

setup.startingCharacters.computerGeek = {
	parent: 'nerd',
	label: 'Computer geek',
	image: 'system/1_openings/2_sg/nerd_3.jpg',
	desc: `You were always into computers, whether it be by playing video games, taking computers apart or learning programing and even hacking. You love everything about computers, but this passion left you little time to make friends - real-life friends, at least. You have managed to befriend many online players that you talk to while you play various video games, however, and you rarely spend any time outdoors, nor money on clothes or other girly stuff. You are far more interested in saving your money for a better computer in order to play even better games.
	You've considered hosting a web series of video games or vlogs - you even took the time to learn how to video edit - but you aren't sure if you want to put yourself out there like that.`,
	pc:{
		bmi: 20,
		hairColor: 3,
		willpowermax: 60
	},
	skills:{
		intelligence:55,
		computer:40,
		hacking:20,
		gaming:30,
	},
	traits:{
	},
	school:{
		grades:{	comp:95}
	},
	location:{
        bedrPar:{
            furniture:{
                computer: {}
            }
        }
    },
	locationTags:{
		homeParents:{
			internet: true
		}
	},
	npcs:{
	},
	wardrobe:{
	}
};

setup.startingCharacters.chessPlayer = {
	parent: 'nerd',
	label: 'Avid chess player',
	image: 'system/1_openings/2_sg/nerd_4.jpg',
	desc: `You were always into chess as a child, and have studied all the great chess masters. You can name them all, as well as their favorite strategies! You find nothing more interesting than matching your wits against someone else's in a game of chess. It has left you with the ability to often see the consequences of your actions better than most as you are used to looking several moves ahead.
	All of this has left you with little time to make many friends, and you rarely spend any time outdoors.`,
	pc:{
		hairColor: 3,
		hairLength: 200,
		willpowermax: 65
	},
	skills:{
		intelligence:55,
		perception:40,
		reaction:40,
		chess:40,
	},
	traits:{
	},
	school:{
	},
	items:{
	},
	npcs:{
	},
	wardrobe:{
	}
};

setup.startingCharacters.jock = {
	parent: 'sg_starting_category',
	label: 'Jock',
	image: 'system/1_openings/2_sg/jock_0.jpg',
	desc: "Jocks and natural athletes - These students are gifted in their chosen sport and are very athletically inclined. This means that they tend to be fit and in good shape, often making them better looking than many of the other students. They get along with other jocks and are respected by the cool kids while being feared by the nerds and losers. They don't value academic achievements and can come into conflict with the gopniks and other troublemakers.",

	pc:{
		bmi: 20,
		legHairVisibility: 2,
		tan: 20
	},

	skills:{
		agility:45,
		bushcraft:5,
		dance:10,
		football:10,
		highHeels:20,
		iceskating:20,
		inhibition:20,
		makeup:30,
		people:10,
		reaction:45,
		run:20,
		spirit:45,
		strength:75,
		vitality:45,
		volleyball:10,

	},

	items:{
		cosmetics: 10,
		hairScrunchie: 10,
		razor: 10,
		sanpad: 20,
		tampon: 20,
	},

	school:{
		grades:{	art:55,	bio:55,	comp:55,	eng:55,	geo:55,	his:55,	lit:55,	math:55,	mus:55,	pe:95,	rus:55,	sci:55,	shop:55	},
		group: 'jocks'
	},
	npcs:{
		bulk:{
			cool:{
				values:{
					fam: 300,
					rel: 55
				}
			},
			jocks:{
				values:{
					fam: 500,
					rel: 65
				}
			}
		}
	},
	wardrobe:{
		itemsByFilter:{
			anyFashionistaPurse:{
				filters:{
					vendor:'fashionista',
					type: 'purse'
				},
				action: 'wear'
			}
		}
	}
};

setup.startingCharacters.volleyball = {
	parent: 'jock',
	label: 'Volleyball player',
	image: 'system/1_openings/2_sg/jock_1.jpg',
	desc: `Ever since the first time you played volleyball, you have been in love with the sport. You spent a lot of your free time trying to improve your ability, and it paid off; you're actually quite good now! Your obsession with volleyball, however, has had some repercussions on your school performance. You're a sub-par student, and you haven't made many friends other than your fellow jocks. You are especially close with <<=$npc('A13').firstname>> and your coach.`,
	pc:{
		bmi: 21,
		hairColor: 3,
		hairLength: 400,
		tits: 3,
		willpowermax: 70
	},
	skills:{
		volleyball:50,
	},
	finances:{
	},
	items:{
	},
	npcs:{
		bulk:{
			cool:{	values:{	fam: 200,	rel: 50}},
			jocks:{	values:{	fam: 300,	rel: 50}},
		},
		ids:{
			A13:{rel: 80,fam:700},
			A69:{rel: 80,fam:700},
		}
	}
};

setup.startingCharacters.dancer = {
	parent: 'jock',
	label: 'Dancer',
	image: 'system/1_openings/2_sg/jock_2.jpg',
	desc: `You fell in love with dancing at an early age and never looked back. You spent a lot of your free time trying to improve your skills, and it paid off; you're actually quite good now!
	<<=$npc('A11').firstname>> helpfully pointed out that an added benefit of dance was a greater increase in your flexibility (that is, of course, typical of <<=$npc('A11').firstname>>). Your obsession with dancing, however, has had some repercussions on your school performance. You're a sub-par student, and you haven't made many friends other than your fellow jocks.
	You are particularly close with <<=$npc('A23').firstname>>, who is just as passionate about dancing as you are. You trained a lot together as children and have a mutual respect for each other's abilities.`,
	pc:{
		bmi: 19,
		hairColor: 0,
		hairLength: 300,
		skinAppearance: 1,
		tan: 5,
		willpowermax: 80
	},
	skills:{
		agility:50,
		charisma:40,
		dance:50,
		highHeels:30,
		inhibition:30,
		makeup:40,
		perform:35,
		spirit:45,
	},
	finances:{
	},
	items:{
	},
	school:{
		grades:{mus:95},
	},
	npcs:{
		bulk:{
		},
		ids:{
			A23:{rel: 85,fam:700},
			A144:{rel: 70,fam:600},
		}
	}
};

// TODO: Eveerything below is dummy

setup.startingCharacters.runner = {
	parent: 'jock',
	label: 'Runner',
	image: 'system/1_openings/2_sg/jock_3.jpg',
	desc: `Ever since you first tried track, you have been in love with the sport. When you're running, the rest of the world fades away and you experience a natural high like no other. You spent a lot of your free time trying to get better at it, and it paid off; you're actually quite good now! Your obsession with running, however, has had some repercussions on your school performance. You're a sub-par student, and you haven't made many friends other than your fellow jocks and your coach.`,
	pc:{
	},
	skills:{
	},
	finances:{
	},
	items:{
	},
	school:{
	},
	npcs:{
	}
};

setup.startingCharacters.football = {
	parent: 'jock',
	label: 'Football player',
	image: 'system/1_openings/2_sg/jock_4.jpg',
	desc: `Ever since your first football game, you have been in love with the sport. You spent a lot of your free time trying to get better at it, and it paid off; you're actually quite good now! Your obsession with football has had some repercussions on your school performance, however, and you're now a sub-par student. You haven't made many friends other than your fellow jocks, especially <<=$npc('A149').firstname>> and your coach.`,
	pc:{
	},
	skills:{
	},
	finances:{
	},
	items:{
	},
	school:{
	},
	npcs:{
	}
};

setup.startingCharacters.cool = {
	parent: 'sg_starting_category',
	label: 'Popular kid',
	image: 'system/1_openings/2_sg/popular_0.jpg',
	desc: `The popular, cool and beautiful - These students are typically socially-gifted and are often blessed with natural good looks. They are envied by many because of this, and most want to be their friends. More than any other clique, they have the ability to ruin someone's reputation and make them social outcasts, which earns them the fear of many students. Being cool and good looking is all they value, so they tend to be subpar both athletically and academically.
	You spent most of your childhood outdoors, playing with other boys and girls. As a result, you're quite healthy and have a keen understanding about how to get yourself out of trouble (or shifting the blame to someone else). You were never very interested in school or sports, however, and are only a sub-par student. Your popularity has negatively impacted your relationship with <<=$npc('A11').firstname>>, and you're not as close as you once were.`,

	pc:{
		bmi: 22,
		legHairVisibility: 1,
		tan: 5,
		teethQuality:0,
		willpowermax: 70
	},

	skills:{
		charisma:45,
		dance:10,
		highHeels:30,
		iceskating:10,
		inhibition:20,
		makeup:40,
		people:30,
		perception: 45,
		persuasion: 30,
		spirit:45,

	},
	finances:{
		cash: 3000
	},
	items:{
		cosmetics: 20,
		hairScrunchie: 10,
		razor: 20,
		sanpad: 20,
		tampon: 20,
	},

	school:{
		grades:{	art:65,	bio:65,	comp:65,	eng:65,	geo:65,	his:65,	lit:65,	math:65,	mus:65,	pe:65,	rus:65,	sci:65,	shop:55	},
		group: 'cool'
	},
	npcs:{
		bulk:{
			cool:{
				values:{
					fam: 500,
					rel: 65
				}
			},
			jocks:{
				values:{
					fam: 300,
					rel: 55
				}
			}
		}
	},
	wardrobe:{
		itemsByFilter:{
			anyFashionistaPurse:{
				filters:{
					vendor:'fashionista',
					type: 'purse'
				},
				action: 'wear'
			}
		}
	}
};

setup.startingCharacters.beautiful = {
	parent: 'cool',
	label: 'Beautiful',
	image: 'system/1_openings/2_sg/popular_2.jpg',
	desc: `You might not be the smartest, be the most social or have the toughest attitude - but what you do have is natural good looks. You blossomed earlier than most girls and the boys took note, especially <<=$npc('A11').firstname>>, who started acting differently around you. As you got older your looks only improved, and you are often considered one of the best looking girls wherever you go.
	You are especially popular with the cool kids and jocks.`,
	pc:{
		bmi: 20,
		faceGeneticAttractiveness:2,
		hairColor: 0,
		hairLength: 400,
		skinAppearance: 2,
		tan: 50,
		tits:4,
		willpowermax: 80
	},
	skills:{
		highHeels:40,
		inhibition:25,
		makeup:50,
		people:20,

	},
	finances:{
	},
	items:{
		comb: 1,
		cosmetics: 50,
		sunblock: 10,
	},
	school:{
		grades:{},
	},
	npcs:{
		bulk:{
		},
		ids:{
		}
	}
};

setup.startingCharacters.sociable = {
	parent: 'cool',
	label: 'Sociable',
	image: 'system/1_openings/2_sg/popular_1.jpg',
	desc: `You're friends with all of the important kids at school, which is what really matters. You were very social growing up and enjoyed being around others, often becoming the center of attention.
	You've always had a knack for knowing the right thing to say at the right moment, which led to many other students wanting to be your friend. You can, with a little work, get along with nearly anyone if you put your mind to it.`,
	pc:{
		hairColor: 3,
		hairLength: 250,
	},
	skills:{
		charisma:50,
		people:40,

	},
	finances:{
	},
	items:{
	},
	school:{
		grades:{},
	},
	npcs:{
		bulk:{
		},
		ids:{
		}
	}
};

setup.startingCharacters.gopnik = {
	parent: 'sg_starting_category',
	label: 'Gopnik',
	image: 'system/1_openings/2_sg/gopnik_0.jpg',
	desc: `Gopniks, rebels, punks and troublemakers - These students don't play by the rules and, in fact, will often happily piss on them if given half a chance. They are in decent shape from all of their fighting and troublemaking, but their predilection for drinking, smoking and drugs often counteracts this to a point. They are not the most well-liked students; teachers and parents alike take a dim view of them, as do the local police. Most students fear them, either from the years of bullying or from the gopniks' willingness to fight. Some students secretly envy their carefree attitude and apparent ability to sneer and wave off many of the social pitfalls that other students face.`,

	pc:{
		bmi: 22,
		legHairVisibility: 4,
		tan: 10,
		willpowermax: 75
	},

	skills:{
		agility:40,
		highHeels:10,
		inhibition:25,
		makeup:25,
		people:10,
		reaction:40,
		run:20,
		spirit:40,
		strength: 50,
		vitality: 40,

	},
	finances:{
	},
	items:{
		cosmetics: 10,
		razor: 10,
		sanpad: 30,
		tampon: 10,
	},

	school:{
		grades:{	art:25,	bio:25,	comp:25,	eng:25,	geo:25,	his:25,	lit:25,	math:25,	mus:25,	pe:80,	rus:25,	sci:25,	shop:80	},
		group: 'gopniks'
	},
	npcs:{
		bulk:{
			gopniks:{
				values:{
					fam: 500,
					rel: 65
				}
			},
			teachers:{
				values:{
					rel: 30
				}
			},
		}
	},
	wardrobe:{
	}
};

setup.startingCharacters.truegopnik = {
	parent: 'gopnik',
	label: 'Gopnik',
	image: 'system/1_openings/2_sg/gopnik_1.jpg',
	desc: `You are a gopnik. While you're still low in the gopnik pecking order, you've already proven yourself to them and most of them accept you as an equal. You have problems at home and school due to your antisocial behavior. This is especially true with your mother and stepfather, who see you going down the wrong path.
	The jocks have a not so friendly rivalry with you and the other gopniks. While you don't get along, some of them have mutal respect for you.`,
	pc:{
		bmi: 23,
		hairColor:1
	},
	skills:{
		defense: 35,
		jabs: 35,
		kick: 35,
		punch: 35,
		strength: 70,
		vitality: 45,

	},
	finances:{
	},
	items:{
	},
	school:{
	},
	npcs:{
		bulk:{
			gopniks:{
				values:{
					fam: 500,
					rel: 75
				}
			},
			parents_social:{
				values:{
					rel: 30
				}
			},
			
		}
	},
	wardrobe:{
	}
};

setup.startingCharacters.troublemaker = {
	parent: 'gopnik',
	label: 'Troublemaker',
	image: 'system/1_openings/2_sg/gopnik_2.jpg',
	desc: `You are a troublemaker. Nothing makes you happier than causing problems, whether it be petty larceny, getting into fights or vandalism. You live for the thrill of breaking the rules. You get along fairly well with the gopniks and they accept you as a kindred spirit, loving your willingness to jump head first into any and all trouble you run across - and if you can't find any, you will happily make your own, which keeps things lively.
	You have problems at home and school due to your antisocial behavior. This is especially true with your mother and stepfather, who see you going down the wrong path. You are well known to both your teachers and the police.`,
	pc:{
		bmi: 20,
		hairColor:0,
		willpowermax: 70
	},
	skills:{
		defense:20,
		inhibition:30,
		jabs: 20,
		kick: 20,
		punch: 20,
		spirit:40,
		strength: 60,
		vitality: 40,

	},
	traits:{
		nerd_points:-50,
	},
	finances:{
	},
	items:{
	},

	npcs:{
		bulk:{
			gopniks:{
				values:{
					fam: 500,
					rel: 75
				}
			},
			parents_social:{
				values:{
					rel: 25
				}
			},
			
		}
	},
	wardrobe:{
		items:{
			dolls_purse_16:'wear'
		}
	}
};

/*setup.startingCharacters.vitekGirlfriend = {
	parent: 'gopnik',
	label: "Vitek's girlfriend",
	image: 'system/1_openings/2_sg/gopnik_3.jpg',
	desc: `You are <<=$npc('A9').nickname_possessive>> girlfriend. You love the thrill and danger of hanging out with the gopniks, even if you lack the true attitude yourself. You met <<=$npc('A9').nickname>> after he and <<=$npc('A11').firstname>> became friends. There was something about his bad boy attitude that drew you in, and you soon found yourself falling for him.
	As you developed, he started to take an interest in you as well and you soon started dating. You're not technically a gopnik - you are considered more of a wannabe - but the rest of the gopniks seem to accept you anyways. You're not sure what would happen if you ever broke up with <<=$npc('A9').nickname>>, however, as being his girlfriend and hanging out with the other gopniks has cost you any real, close friends outside of their group.`,
	pc:{
		bmi: 20,
		hairColor:0,
		tits:4,
		willpowermax: 70
	},
	skills:{
		defense:20,
		inhibition:30,
		jabs: 20,
		kick: 20,
		punch: 20,
		spirit:40,
		strength: 60,
		vitality: 40,

	},
	traits:{
		nerd_points:-50,
	},
	finances:{
	},
	items:{
	},

	npcs:{
		bulk:{
			gopniks:{
				values:{
					fam: 500,
					rel: 75
				}
			},
			parents_social:{
				values:{
					rel: 25
				}
			},
			
		}
	},
	wardrobe:{
		items:{
			dolls_purse_16:'wear'
		}
	}
};*/

setup.startingCharacters.outcast = {
	parent: 'sg_starting_category',
	label: 'Social Outcast',
	image: 'system/1_openings/2_sg/outcast_0.jpg',
	desc: `Losers, teachers' pets, sluts and the ugly - These students are the outcasts, the people no one likes to spend time with, other than to bully them. Perhaps they are just socially awkward and never made many friends, broke one of the unwritten social rules, are ugly, a snitch, a slut and/or an outed gay boy. Either way, they all have one thing in common: they are easy targets to bully and mock.`,

	pc:{
		bmi: 22,
		legHairVisibility: 4,
		tan: 10,
		willpowermax: 75
	},
/*
	skills:{
		agility:40,
		highHeels:10,
		inhibition:25,
		makeup:25,
		people:10,
		reaction:40,
		run:20,
		spirit:40,
		strength: 50,
		vitality: 40,

	},
	finances:{
	},
	items:{
		cosmetics: 10,
		razor: 10,
		sanpad: 30,
		tampon: 10,
	},
*/
	school:{
		grades:{	art:50,	bio:50,	comp:50,	eng:50,	geo:50,	his:50,	lit:50,	math:50,	mus:50,	pe:50,	rus:50,	sci:50,	shop:50	},
		group: 'outcasts'
	},/*
	npcs:{
		bulk:{
			gopniks:{
				values:{
					fam: 500,
					rel: 65
				}
			},
			teachers:{
				values:{
					rel: 30
				}
			},
		}
	},
	wardrobe:{
	}*/
};

setup.startingCharacters.ugly = {
	parent: 'outcast',
	label: 'Ugly duckling',
	image: 'system/1_openings/2_sg/outcast_2.jpg',
	desc: `Some girls blossom early and others have natural good looks - you got neither. In fact, you seem to have been cursed with an androgynous face and body, and have been mistaken for a boy more times than you would care to admit.
	Your body seems to have grown out of sync, leaving you looking odd and, at best, unattractive for most of your life. Now in your teens, your body is starting to even out in growth, but you're still very androgynous and still considered ugly.
	Your lack of good looks has made you a social pariah. Nobody seems to like you or want to spend time with you unless they are making fun of you.`,
	pc:{
		bmi: 31,
		faceGeneticAttractiveness: -2,
		hairColor:2,
		tits:5,
		willpowermax: 55
	},
	skills:{
		inhibition: 5
	}
}